@@ -32,20 +32,18 @@ class NullOutput(object):
 
 def _customize_sanitizer(fp):
 
-
     bad_attributes = [
         "align",
         "valign",
         "hspace",
-        "class",
         "width",
         "height"
     ]
     
     for item in bad_attributes:
         try:
-            if item in fp._HTMLSanitizer.acceptable_attributes:
-                fp._HTMLSanitizer.acceptable_attributes.remove(item)
+            if item in fp.sanitizer._HTMLSanitizer.acceptable_attributes:
+                fp.sanitizer._HTMLSanitizer.acceptable_attributes.remove(item)
         except Exception:
             logging.debug("Could not remove {}".format(item))
             
@@ -184,7 +182,6 @@ def read_feed(source_feed, output=NullOutput()):
         source_feed.last_result = "Unhandled Case"
         output.write(str(ret))
     except Exception as ex:
-        logging.error("Fetch feed error: " + str(ex))
         source_feed.last_result = ("Fetch error:" + str(ex))[:255]
         source_feed.status_code = 0
         output.write("\nFetch error: " + str(ex))
@@ -317,7 +314,7 @@ def read_feed(source_feed, output=NullOutput()):
 
 
         except Exception as ex:     
-            source_feed.last_result = ("Failed Redirection to " + new_url +  " " + str(ex))["255"]
+            source_feed.last_result = ("Failed Redirection to " + new_url +  " " + str(ex))[:255]
             source_feed.interval += 60
     
     #NOT ELIF, WE HAVE TO START THE IF AGAIN TO COPE WTIH 302
@@ -525,10 +522,12 @@ def parse_feed_xml(source_feed, feed_content, output):
 
                 try:
                     p.created  = datetime.datetime.fromtimestamp(time.mktime(e.published_parsed)).replace(tzinfo=timezone.utc)
-
                 except Exception as ex2:
-                    output.write("CREATED ERROR:" + str(ex2))     
-                    p.created  = timezone.now()
+                    try:
+                        p.created  = datetime.datetime.fromtimestamp(time.mktime(e.updated_parsed)).replace(tzinfo=timezone.utc)
+                    except Exception as ex3:
+                        output.write("CREATED ERROR:" + str(ex3))
+                        p.created  = timezone.now()
 
 
                 p.source = source_feed
@@ -573,16 +572,43 @@ def parse_feed_xml(source_feed, feed_content, output):
             
             try:
                 seen_files = []
+                
+                post_files = e["enclosures"]
+                non_dupes = []
+                
+                # find any files in media_content that aren't already declared as enclosures
+                for ee in e["media_content"]:
+                    found = False
+                    for ff in post_files:
+                        if ff["href"] == ee["url"]:
+                            found = True
+                            break
+                    if not found:
+                        non_dupes.append(ee)
+                        
+                post_files += non_dupes
+                
+                
                 for ee in list(p.enclosures.all()):
                     # check existing enclosure is still there
                     found_enclosure = False
-                    for pe in e["enclosures"]:
+                    for pe in post_files:
+                    
+                        href = "href"
+                        if href not in pe:
+                            import pdb; pdb.set_trace()
+                            href = "url"
+
+                        length = "length"
+                        if length not in pe:
+                            length = "filesize"
+                    
                     
                         if pe["href"] == ee.href and ee.href not in seen_files:
                             found_enclosure = True
                         
                             try:
-                                ee.length = int(pe["length"])
+                                ee.length = int(pe[length])
                             except:
                                 ee.length = 0
 
@@ -598,12 +624,21 @@ def parse_feed_xml(source_feed, feed_content, output):
                         ee.delete()
                     seen_files.append(ee.href)
     
-                for pe in e["enclosures"]:
+                for pe in post_files:
+
+                    href = "href"
+                    if href not in pe:
+                        href = "url"
+
+                    length = "length"
+                    if length not in pe:
+                        length = "filesize"
+
                     try:
-                        if pe["href"] not in seen_files:
+                        if pe[href] not in seen_files:
                     
                             try:
-                                length = int(pe["length"])
+                                length = int(pe[length])
                             except:
                                 length = 0
                             
@@ -612,7 +647,7 @@ def parse_feed_xml(source_feed, feed_content, output):
                             except:
                                 type = "audio/mpeg"
                     
-                            ee = Enclosure(post=p , href=pe["href"], length=length, type=type)
+                            ee = Enclosure(post=p, href=pe[href], length=length, type=type)
                             ee.save()
                     except Exception as ex:
                         pass
@@ -675,14 +710,14 @@ def parse_feed_json(source_feed, feed_content, output):
         try:
             if "description" in f:
                 _customize_sanitizer(parser)
-                source_feed.description = parser._sanitizeHTML(f["description"], "utf-8", 'text/html')
+                source_feed.description = parser.sanitizer._sanitize_html(f["description"], "utf-8", 'text/html')
                 source_feed.save(update_fields=["description"])
         except Exception as ex:
             pass
                     
         try:
             _customize_sanitizer(parser)
-            source_feed.name = parser._sanitizeHTML(source_feed.name, "utf-8", 'text/html')
+            source_feed.name = parser.sanitizer._sanitize_html(source_feed.name, "utf-8", 'text/html')
             source_feed.save(update_fields=["name"])
 
         except Exception as ex:
@@ -735,11 +770,10 @@ def parse_feed_json(source_feed, feed_content, output):
                 title = ""      
                 
             # borrow the RSS parser's sanitizer
-            
             _customize_sanitizer(parser)
-            body  = parser._sanitizeHTML(body, "utf-8", 'text/html') # TODO: validate charset ??
+            body = parser.sanitizer._sanitize_html(body, "utf-8", 'text/html') # TODO: validate charset ??
             _customize_sanitizer(parser)
-            title = parser._sanitizeHTML(title, "utf-8", 'text/html') # TODO: validate charset ??
+            title = parser.sanitizer._sanitize_html(title, "utf-8", 'text/html') # TODO: validate charset ??
             # no other fields are ever marked as |safe in the templates
 
             if "banner_image" in e:
